# -*- coding: utf-8 -*-
# @Author   : Ecohnoch(xcy)
# @File     : configs.py
# @Function : TODO

interval = 0.3
max_interval = 10

login_url = 'http://120.26.143.61/login'
face_upload_url = 'http://120.26.143.61/face_upload'
face_submit_url = 'http://120.26.143.61/face_submit'
face_result_url = 'http://120.26.143.61/get_result'

speaker_upload_url = 'http://120.26.143.61/speaker_upload'
speaker_submit_url = 'http://120.26.143.61/speaker_submit'
speaker_result_url = 'http://120.26.143.61/speaker/get_result'

face_detection_upload_url = 'http://120.26.143.61/face_detection_upload'
face_detection_result_url = 'http://120.26.143.61/face_detection/get_result'

deepface_upload_url = 'http://120.26.143.61/deepface_upload'
deepface_submit_url = 'http://120.26.143.61/deepface_submit'
deepface_result_url = 'http://120.26.143.61/deepface/get_result'

deepface2_upload_url = 'http://120.26.143.61/deepface2_upload'
deepface2_submit_url = 'http://120.26.143.61/deepface2_submit'
deepface2_result_url = 'http://120.26.143.61/deepface2/get_result'

deepface3_upload_url = 'http://120.26.143.61/deepface3_upload'
deepface3_submit_url = 'http://120.26.143.61/deepface3_submit'
deepface3_result_url = 'http://120.26.143.61/deepface3/get_result'