# -*- coding: utf-8 -*-
# @Author   : Ecohnoch(xcy)
# @File     : __init__.py.py
# @Function : TODO

from vsource_algorithm.loginInstance import login
from vsource_algorithm.algorithms.face_recognition import face_recognition
from vsource_algorithm.algorithms.face_detection import face_detection
from vsource_algorithm.algorithms.face_attribute import face_attribute
from vsource_algorithm.algorithms.speaker_recognition import speaker_recognition

from vsource_algorithm.scripts.algorithm_scripts.algorithms import parse_algorithm

